### Use this script to derive any effect concentation required for
### toxicity of barium to the tropical freshwater alga Chlorella sp. 12 and the water flea
### Ceriodaphnia dubia in different water types (e.g. SSW, SSW-Cl and DMW) 
### Save the supplemental csv data files containing the raw data to "C:\drcinput" and copy and paste
### this entire script into the console window of the latest version of R
### (download from this website https://cran.r-project.org/bin/windows/base/). 
### The output will appear on the screen as soon as the script is pasted in.
### Refer to Ritz et al. (2015) for model equations:
### Ritz C, Baty F, Streibig JC, Gerhard D. 2015. Dose-response analysis using R. PLoS ONE 10.


### install the drc package to derive the effect concentrations
library(drc)

###################################################################################
### Effect concentrations for barium toxicity to the tropical freshwater alga
### Chlorella sp. 12 when in SSW medium as a function of the nominal total barium concentration


setwd("C:/drcinput")

A160628_alga_nom_SSW <- read.table("160628_alga_nom_SSW.csv", header=TRUE, sep=",")
A160628_alga_nom_SSW.m3 <- drm(response ~ dose, data = A160628_alga_nom_SSW, fct = W2.4(fixed=c(NA,0,100,NA)))
summary(A160628_alga_nom_SSW.m3)
modelFit(A160628_alga_nom_SSW.m3) 
AIC(A160628_alga_nom_SSW.m3) 
plot(A160628_alga_nom_SSW.m3, main="Barium toxicity to Chlorella sp. 12
     as a function of nominal total barium in SSW ", xlab ="Barium (mg/L)", ylab="% growth rate relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))


### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)
ED(A160628_alga_nom_SSW.m3,c(10,20,50,90),interval="delta")

###################################################################################

### Effect concentrations for barium toxicity to the tropical freshwater alga
### Chlorella sp. 12 when in SSW-Cl medium as a function of the measured dissolved
### barium concentration

setwd("C:/drcinput")


A160823_160906_170606_alga_diss_SSWCl <- read.table("160823_160906_170606_alga_diss_SSW-Cl.csv", header=TRUE, sep=",")
A160823_160906_170606_alga_diss_SSWCl.m2 <- drm(response ~ dose, data = A160823_160906_170606_alga_diss_SSWCl, fct = W1.4(fixed=c(NA,0,100,NA)))
summary(A160823_160906_170606_alga_diss_SSWCl.m2) 
modelFit(A160823_160906_170606_alga_diss_SSWCl.m2) 
AIC(A160823_160906_170606_alga_diss_SSWCl.m2) 
plot(A160823_160906_170606_alga_diss_SSWCl.m2, main="Toxicity of measured dissolved barium to Chlorella
     sp. 12 in SSW-Cl 160823_160906_170606", xlab ="Barium (mg/L)", ylab="% growth rate relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))

### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)
ED(A160823_160906_170606_alga_diss_SSWCl.m2,c(10,20,50,90),interval="delta")



###################################################################################

### Effect concentrations for barium toxicity to the tropical freshwater alga
### Chlorella sp. 12 when in SSW-Cl medium as a function of the measured total
### barium concentration

setwd("C:/drcinput")

A160823_160906_170606_alga_tot_SSWCl <- read.table("160823_160906_170606_alga_tot_SSW-Cl.csv", header=TRUE, sep=",")
A160823_160906_170606_alga_tot_SSWCl.m2 <- drm(response ~ dose, data = A160823_160906_170606_alga_tot_SSWCl, fct = W1.4(fixed=c(NA,0,100,NA)))
summary(A160823_160906_170606_alga_tot_SSWCl.m2) 
modelFit(A160823_160906_170606_alga_tot_SSWCl.m2) 
AIC(A160823_160906_170606_alga_tot_SSWCl.m2) 
plot(A160823_160906_170606_alga_tot_SSWCl.m2, main="Toxicity of measured total barium to Chlorella
     sp. 12 in SSW-Cl 160823_160906_170606", xlab ="Barium (mg/L)", ylab="% growth rate relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))

### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)
ED(A160823_160906_170606_alga_tot_SSWCl.m2,c(10,20,50,90),interval="delta")


######################################################################################

### Effect concentrations for barium toxicity to the freshwater water flea
### Ceriodaphnia dubia when in DMW medium as a function of the nominal total
### barium concentration

setwd("C:/drcinput")

A160615_WF_nom_DMW <- read.table("160615_WF_nom_DMW.csv", header=TRUE, sep=",")
A160615_WF_nom_DMW.m1 <- drm(response ~ dose, data = A160615_WF_nom_DMW, fct = LL.4(fixed=c(NA,0,100,NA)))
summary(A160615_WF_nom_DMW.m1) 
modelFit(A160615_WF_nom_DMW.m1) 
AIC(A160615_WF_nom_DMW.m1) 
plot(A160615_WF_nom_DMW.m1, main="Toxicity of nominal total barium to the water flea 
Ceriodaphnia dubia in DMW", xlab ="Barium (mg/L)", ylab="% immobility relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))


### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)
ED(A160615_WF_nom_DMW.m1,c(10,20,50,90),interval="delta")



######################################################################################

### Effect concentrations for barium toxicity to the freshwater water flea
### Ceriodaphnia dubia when in DMW medium as a function of the measured dissolved
### barium concentration

setwd("C:/drcinput")

A160615_WF_diss_DMW <- read.table("160615_WF_diss_DMW.csv", header=TRUE, sep=",")
A160615_WF_diss_DMW.m1 <- drm(response ~ dose, data = A160615_WF_diss_DMW, fct = LL.4(fixed=c(NA,0,100,NA)))
summary(A160615_WF_diss_DMW.m1) 
modelFit(A160615_WF_diss_DMW.m1) 
AIC(A160615_WF_diss_DMW.m1) 
plot(A160615_WF_diss_DMW.m1, main="Toxicity of measured dissolved barium to the water flea 
Ceriodaphnia dubia in DMW", xlab ="Barium (mg/L)", ylab="% immobility relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))


### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)
ED(A160615_WF_diss_DMW.m1,c(10,20,50,90),interval="delta")


######################################################################################

### Effect concentrations for barium toxicity to the freshwater water flea
### Ceriodaphnia dubia when in SSW-Cl medium as a function of the measured total
### barium concentration

setwd("C:/drcinput")

APool_WF_tot_SSWCl <- read.table("Pool_WF_tot_SSWCl.csv", header=TRUE, sep=",")
APool_WF_tot_SSWCl.m3 <- drm(response ~ dose, data = APool_WF_tot_SSWCl, fct = W2.4(fixed=c(NA,0,100,NA)))
summary(APool_WF_tot_SSWCl.m3)
modelFit(APool_WF_tot_SSWCl.m3) 
AIC(APool_WF_tot_SSWCl.m3) 
plot(APool_WF_tot_SSWCl.m3, main="Toxicity of measured total barium to the water flea
Ceriodaphnia dubia in SSW-Cl", xlab ="Barium (mg/L)", ylab="% immobility relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))

### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)
ED(APool_WF_tot_SSWCl.m3,c(10,20,50,90),interval="delta")


######################################################################################

### Effect concentrations for barium toxicity to the freshwater water flea
### Ceriodaphnia dubia when in SSW-Cl medium as a function of the measured dissolved
### barium concentration

setwd("C:/drcinput")

APool_WF_diss_SSWCl <- read.table("Pool_WF_diss_SSWCl.csv", header=TRUE, sep=",")
APool_WF_diss_SSWCl.m3 <- drm(response ~ dose, data = APool_WF_diss_SSWCl, fct = W2.4(fixed=c(NA,0,100,NA)))
summary(APool_WF_diss_SSWCl.m3)
modelFit(APool_WF_diss_SSWCl.m3) 
AIC(APool_WF_diss_SSWCl.m3) 
plot(APool_WF_diss_SSWCl.m3, main="Toxicity of measured dissolved barium to the water flea
Ceriodaphnia dubia in SSW-Cl", xlab ="Barium (mg/L)", ylab="% immobility relative to control ", lwd=2,
     cex=1.2, cex.axis=1.2, cex.lab=1.2, type="all", pch=19, ylim=c(0,120))


### Currently this script will provide the EC10, 20, 50 and 90 values
### Enter additional effect concentrations by typing in the desired percentage effect 
### within the brackets followed by a comma e.g. c(10, 15, 20, 25, 50, 75, 90, 95)

ED(APool_WF_diss_SSWCl.m3,c(10,20,50,90),interval="delta")




